==> xlniuxdata-vipgame-1.0.31-20151022.063723-16-sources.jar: com/xunlei/niux/data/vipgame/vo/vic/PersonInfo.java <==
package com.xunlei.niux.data.vipgame.vo.vic;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="vic_person_info",pkFieldName="seqid",pkFieldAssign=false)
public class PersonInfo {
    private Long seqid;
    private Long uid;
    private String realName;
    private String mobileNumber;
    private String qqNumber;
    private String sex;
    private Integer age;
    private String birthday;
    private String address;
    private String degree;
    private String job;
    private String annualSalary;
    private String placeProvince;
    private String placeCity;
    private String family;
    private String lostLogin;
    private String lostPay;

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }

    public String getAnnualSalary() {
        return annualSalary;
    }

    public void setAnnualSalary(String annualSalary) {
        this.annualSalary = annualSalary;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getDegree() {
        return degree;
    }

    public void setDegree(String degree) {
        this.degree = degree;
    }

    public String getFamily() {
        return family;
    }

    public void setFamily(String family) {
        this.family = family;
    }

    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getMobileNumber() {
        return mobileNumber;
    }

    public void setMobileNumber(String mobileNumber) {
        this.mobileNumber = mobileNumber;
    }

    public String getPlaceCity() {
        return placeCity;
    }

    public void setPlaceCity(String placeCity) {
        this.placeCity = placeCity;
    }

    public String getPlaceProvince() {
        return placeProvince;
    }

    public void setPlaceProvince(String placeProvince) {
        this.placeProvince = placeProvince;
    }

    public String getQqNumber() {
        return qqNumber;
    }

    public void setQqNumber(String qqNumber) {
        this.qqNumber = qqNumber;
    }

    public String getRealName() {
        return realName;
    }

    public void setRealName(String realName) {
        this.realName = realName;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }
}

==> xlniuxdata-vipgame-1.0.43-20160125.081729-9-sources.jar: com/xunlei/niux/data/vipgame/vo/vic/PersonInfo.java <==
package com.xunlei.niux.data.vipgame.vo.vic;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="vic_person_info",pkFieldName="seqid",pkFieldAssign=false)
public class PersonInfo {
    private Long seqid;
    private Long uid;
    private String realName;
    private String mobileNumber;
    private String qqNumber;
    private String sex;
    private Integer age;
    private String birthday;
    private String address;
    private String degree;
    private String job;
    private String annualSalary;
    private String placeProvince;
    private String placeCity;
    private String family;
    private String lostLogin;
    private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;

    public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }

    public String getAnnualSalary() {
        return annualSalary;
    }

    public void setAnnualSalary(String annualSalary) {
        this.annualSalary = annualSalary;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getDegree() {
        return degree;
    }

    public void setDegree(String degree) {
        this.degree = degree;
    }

    public String getFamily() {
        return family;
    }

    public void setFamily(String family) {
        this.family = family;
    }

    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getMobileNumber() {
        return mobileNumber;
    }

    public void setMobileNumber(String mobileNumber) {
        this.mobileNumber = mobileNumber;
    }

    public String getPlaceCity() {
        return placeCity;
    }

    public void setPlaceCity(String placeCity) {
        this.placeCity = placeCity;
    }

    public String getPlaceProvince() {
        return placeProvince;
    }

    public void setPlaceProvince(String placeProvince) {
        this.placeProvince = placeProvince;
    }

    public String getQqNumber() {
        return qqNumber;
    }

    public void setQqNumber(String qqNumber) {
        this.qqNumber = qqNumber;
    }

    public String getRealName() {
        return realName;
    }

    public void setRealName(String realName) {
        this.realName = realName;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }
}
